
%%                                                       STAGtimedat  8.02

%                                                  plots StagYY's time.dat
%    . calls f_DesignBackground
%    . calls f_DefaultsTimedat
%    . calls f_Dimensions
%    . calls f_DesignFigure
%    . calls f_FileFinder
%    . calls f_saveData
%    . calls f_Import
%    . calls f_saveFigure
%    . calls f_SetupFigure
%    . calls f_DesignVaria
%                                               23.02.2018 : Fabio Crameri

%% UPDATES >8.0
% *compatibility improvements to new StagYY version*
% *bug fixes*

%% UPDATES 8.0
% *additional parameters added*
% *deeper fAIo integration*
% *using improved fileFinder*
% *more flexible file read*
% *automatic data size limitation*
% *more informative file naming*
% *option to name files manually*
% *option to handle time.dat files without header*
% *option to save processed graph data*
% *option to set default screen position of figure*
% *option for quick mode*
% *speed improvements*
% *bug fixes*

%% UPDATES 7.0
% *more stable design-routines*
% *cleaner plot design and layout*
% *automatic figure size*

%% UPDATES 6.0
% *improved plot layout*
% *improved code design*
% *bug fixes to dimensionalisation*

function [SAVE] = STAGtimedat(IN,PLOT,SWITCH,STYLE,SAVE)
if exist('IN','var') %if run from a parfile
    %% DEFAULT VARIABLES
    %...see f_DefaultsTimedat.m
else
    clear;
    %% INPUT (...use parameter file instead)
    SAVE.StartNumber = 1; SAVE.EndNumber = 1;
    [IN,PLOT,SWITCH,STYLE,SAVE] = f_DefaultsTimedat; %get default variables
    IN.Name         =   {  'testDIM'  'testDIM' };	% filename
    IN.Parameter    =   [   11        	];
    IN.Folder       =   {   '/work/plotTest'   };
end

%% STARTUP PROCEDURE
SAVE.app = 'STAGtimedat'; SAVE.appVersion = 8.02; %only 3 digits to prevent unecessary parfile updates
if ~isfield(SAVE,'count'); SAVE.count = 0; end
[fAIo,SAVE,SWITCH] = f_Startup(PLOT,SAVE,SWITCH);
if ~strcmp(fAIo.Status,'all fine!'); disp(' '); disp(['                         ',char(10004),' Finished.']); return; end

%% VARIABLE ADJUSTMENTS
nrModels = length(IN.Name);
if SWITCH.QuickMode
    SAVE.Figure                  	=   false;
    SWITCH.PlotDesign               =   false;
    SWITCH.BackgroundDesign     	=   false;
    SWITCH.LegendDesign          	=   false;
    SWITCH.SimplifyPlots           	=   false;
    SWITCH.Annotation               =   false;
end
if isfield(PLOT,'titleString') && length(PLOT.titleString)>nrModels
    PLOT.titleString(:,nrModels+1:end)  = [];
end
% check for length of number input arrays
if length(IN.Parameter)<nrModels
    dummy = ones(1,nrModels-length(IN.Parameter)); dummy(:) = IN.Parameter(1,1);
    IN.Parameter = [IN.Parameter, dummy];
end
% check for length of string input arrays
if length(IN.Folder)<nrModels
    dummy = cell(1,nrModels-length(IN.Folder)); dummy(:) = IN.Folder(1,1);
    IN.Folder = [IN.Folder, dummy];
end

%% GET NUMBER OF SUBPLOTS
nrPlots=0;                                                               % timedat label
if PLOT.Temperature;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Tmean'}; end
if PLOT.Viscosity;      	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'eta_mean'}; end
if PLOT.Velocity;           nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Vrms'}; end
if PLOT.Ra_eff;             nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'ra_eff'}; end
if PLOT.Nu_top;             nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Nu_top'}; end
if PLOT.Nu_bot;             nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Nu_bot'}; end
if PLOT.InternalHeating;	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'H_int'}; end
if PLOT.Composition;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'C_mean'}; end
if PLOT.HeatfluxTop;    	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'F_bot'}; end
if PLOT.HeatfluxBot;    	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'F_top'}; end
if PLOT.EruptionRate;   	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'erupt_rate'}; end
if PLOT.EruptHeatFlux;   	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'erupt_heatflux'}; end
if PLOT.Erupta;             nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'erupta'}; end
if PLOT.Entrainment;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'entrainment'}; end
if PLOT.Cmass_error;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Cmass_error'}; end
%new options - need to be tested!
if PLOT.TotalErupta;      	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'erupta_total'}; end
if PLOT.OutgassedWater;    	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'outgassed_water'}; end
if PLOT.SurfaceTemperature;	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Tsurf'}; end
if PLOT.CMB_Temperature;   	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Tcmb'}; end
if PLOT.Psurf;              nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'Psurf'}; end
if PLOT.Weathering;         nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'weathering'}; end
if PLOT.TotalWater;         nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'mH2O_total'}; end
if PLOT.MantleWater;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'mH2O_mantle'}; end
if PLOT.CrustWater;         nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'mH2O_crust'}; end
if PLOT.dmH2O;              nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'dmH2O'}; end
if PLOT.OutgassedCarbon; 	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'outgassed_carbon'}; end
if PLOT.OutgassedNitrogen; 	nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'outgassed_nitrogen'}; end
%these have to be last
if PLOT.Timesteps;          nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'istep'}; end
if PLOT.Performance;        nrPlots = nrPlots+1; DATA.string(1,nrPlots)={'istep'}; end

%% LAYOUT SUBPLOTS
if nrPlots<=4
    nxSubplots  = 1;
    nzSubplots  = nrPlots;
else
    nxSubplots  = min(nrPlots,2);
    nzSubplots  = floor((nrPlots+1)/2);
end

%% SETUP FIGURE
if ~SWITCH.QuickMode
    clf(figure(1));
    %color mode
    if strcmp(STYLE.ColorMode,'light')
        STYLE.ColorModeBW   = 'white';
    elseif strcmp(STYLE.ColorMode,'dark')
        STYLE.ColorModeBW   = 'black';
    end
    set(gcf,'color',STYLE.ColorModeBW);
    % set figure position
    if strcmp(SWITCH.FigurePosition,'auto') %set figure position automatically
        FPOS.Default            = PLOT.FigureDefaultPosition;
        FPOS.subplotLayout      = [nzSubplots nxSubplots];
        [~] = f_SetupFigure(FPOS,SAVE,1,1);
    else %set figure position manually
        set(gcf,'Position',SWITCH.FigurePosition);
    end
end

h_runs = zeros(size(IN.Name,2),1);
for irun=1:size(IN.Name,2)
    clearvars -except IN PLOT SWITCH STYLE SAVE DATA irun h_runs nrPlots nxSubplots nzSubplots
    
    %% VARIABLE CONVERSION & SETUP
    FILE.name         	= IN.Name{irun};
    FILE.stemRead     	= IN.Folder{irun};
    FILE.stemSave     	= IN.Folder{irun};
    SWITCH.parameter    = IN.Parameter(irun);
    lineColor           = PLOT.ColorVector(irun,:);
    
    %% CHECK FOR INPUT FILE
    [FILE] = f_FileFinder(FILE,SWITCH,SAVE);
    if FILE.NotFound
        SAVE.LastFile           = true;
        close all
        disp([FILE.NotFoundError])
        return
        
    end
    
    %% OPEN FILE AND CHECK FILE SIZE    
    if SWITCH.closeOldWaitbars; wbOld = findall(0,'tag','TMWWaitbar'); delete(wbOld); end %close open ghost waitbars
    wb = waitbar(0,'Please wait...');
    %find header entries in first line automatically
    fid             = fopen(FILE.found,'r');
    iCol=0;
    entry=1;
    while (entry~='0')
        entry               = fscanf(fid,'%s',[1 1]);
        iCol                = iCol+1;
        DATA.title{1,iCol}  = entry;
    end
    fclose(fid);
    DATA.title(:,end)   = []; %remove the last entry (i.e., 0)
    waitbar(1/6,wb)
    %find number of columns
    fid             = fopen(FILE.found,'r');
    nColumns=0; iLine=0;
    while nColumns<10 %line has less than 10 entries/columns (i.e., is empty)
        iLine       = iLine+1;
        nColumns  	= numel(regexp(fgetl(fid),'\s*([^\s]*)\s*'));
    end
    fclose(fid);
    waitbar(2/6,wb)

    %% IMPORT & READING DATA
    DATA.filename       = FILE.found;
    DATA.titleRow    	= true;
    DATA.numberEntries  = nColumns;
    DATA.startRow       = iLine;
    if isempty(DATA.title)
        DATA.titleRow 	= false;
    end
    DATA.Task           = 'ImportTimedat';
    [DATA,~] = f_Import(DATA);
    waitbar(5/6,wb)
    if ~(nColumns==39 || nColumns==27 || nColumns==17 || nColumns==0)
        warning('Number of columns in time.dat is different from expected formats! Check if this needs an update!')
    end
    nRows               = size(DATA.Array{1},1);
    timeRow             = find(strcmp(DATA.title,'time'));
    if ~DATA.titleRow
        timeRow         = 2;
    end
    waitbar(6/6,wb)
    close(wb)

    %% DISPLAY MODEL DETAILS I
    if SWITCH.Verbose
        % disp(['datafile is ',num2str(n),' x ',num2str(nLines)])
        disp(['Data Structure:       __',num2str(nColumns),'__>'])
        disp('                     |')
        disp(['                   ',num2str(nRows)])
        disp('                     |')
        disp('                     V')
    end
    
    %% DATA SIZE ADJUSTMENTS
    nRowsAdjusted = nRows;
    numDataPointsThreshold  	= 5e4;
    if nRows>numDataPointsThreshold
        while nRowsAdjusted>numDataPointsThreshold
            for icol=1:size(DATA.Array,2)
                DATA.Array{1,icol}(1:2:end-1,:)    = []; %remove every second entry
            end
            nRowsAdjusted     	= size(DATA.Array{1,icol}(:),1);
        end
        disp(['                   ',char(10551),' Data size reduced to ',num2str(nRowsAdjusted)])
    end
    
    %% fAIO ACTION: UPDATE CACHE
    fAIo.task   = 'handleCache';
    [fAIo,SAVE] = f_AIo(fAIo,SWITCH,FILE,[],STYLE,SAVE);
    
    %% CHECK FOR DIMENSIONAL INPUT:
    %get time after first timestep
    dummy = DATA.Array{1,timeRow}(2,1);
    if dummy>1e2  %if first timestep > 100 (years) then DIMENSIONAL INPUT
        SWITCH.DimensionalInput = true; dimString = 'dimensional';
        SWITCH.DimensionalMode = true; %set output to dimensional if input is dimensional
    else
        SWITCH.DimensionalInput = false; dimString = 'non-dimensional';
    end
    disp(['Data:              ',SWITCH.GeodynamicCode,', ',dimString])
    
    %% DIMENSIONALIZATION
    [SETUP,SWITCH] = f_Dimensions(SWITCH,FILE);
    
    % SET TIME
    PLOT.time         	= DATA.Array{1,timeRow};
    PLOT.time_dim     	= DATA.Array{1,timeRow}*SETUP.timescale/SETUP.secyear;  %get dimensional time [a]
    
    dummy = max(PLOT.time_dim); %[a]
    if dummy>100*1e6 %>100Ma
        PLOT.time2plot = PLOT.time_dim/1e9; PLOT.time2plotDim = 'Ga'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e9;
    elseif dummy<1e-3 %<0.001a
        PLOT.time2plot = PLOT.time_dim*SETUP.secyear; PLOT.time2plotDim = 's'; PLOT.timeConvert = SETUP.timescale;
    elseif dummy<1e2 %<100a
        PLOT.time2plot = PLOT.time_dim; PLOT.time2plotDim = 'a'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear;
    elseif dummy<1e5 %<0.1Ma
        PLOT.time2plot = PLOT.time_dim/1e3; PLOT.time2plotDim = 'ka'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e3;
    else
        PLOT.time2plot = PLOT.time_dim/1e6; PLOT.time2plotDim = 'Ma'; PLOT.timeConvert = SETUP.timescale/SETUP.secyear/1e6;
    end
    if ~SWITCH.DimensionalMode && ~SWITCH.DimensionalInput; PLOT.time2plot = PLOT.time; PLOT.time2plotDim = 'nd'; PLOT.timeConvert = 1; end
    
    DATA.Array{1,timeRow}       = PLOT.time2plot; %dimensionalise time array
    
    minTime                     = min(PLOT.time); %[nd or s]
    maxTime                     = max(PLOT.time); %[nd or s]
    minTimeDim                  = minTime*PLOT.timeConvert; %[plotting dimension]
    maxTimeDim                  = maxTime*PLOT.timeConvert; %[plotting dimension]
    
    %  1       2   3     4      5   6      7   8    9    10   11        12      13      14      15   16
    %  istep time F_top F_bot Tmin Tmean Tmax Vmin Vrms Vmax eta_min eta_mean eta_max ra_eff Nu_top Nu_bot
    
    %  17       18   19     20    21      22        23      24              25          26       27
    %  C_min C_mean C_max F_mean F_max erupt_rate erupta erupt_heatflux entrainment Cmass_error H_int
    
    
%     istep  time  F_top  F_bot   Tmin  Tmean Tmax  Vmin  Vrms Vmax  eta_min  eta_mean  eta_max   ra_eff Nu_top  Nu_bot   
% C_min  C_mean  C_max  F_mean  F_max  erupt_rate  erupta erupt_heatflux entrainment Cmass_error  H_int  

% erupta_total  outgassed_water  Tsurf  Tcmb  Psurf  weathering  mH2O_total  mH2O_mantle  mH2O_crust  dmH2O  outgassed_carbon  outgassed_nitrogen
    
    %% SET UP FIELD VARIABLES
    %  	1                 	2                   3                   4                   5                   6
    %  	data name           variable label      time.dat label    	dim. scale      	data dimension      individual range
    FIELD_M = {
        'Time Steps'        'cumul. time steps' 'istep'          	1                   '#'                 false           %1
        'Time'              'time'              'time'           	PLOT.timeConvert    PLOT.time2plotDim   false           %2
        'Top Heatflux'     	'F_{top}'           'F_top'             SETUP.HFscale      	SETUP.HFDim       	false           %3
        'Bottom Heatflux'  	'F_{bot}'           'F_bot'             SETUP.HFscale    	SETUP.HFDim       	false           %4
        'Min. Temperature'  'T_{min}'           'Tmin'              SETUP.Tscale        SETUP.TDim       	false           %5
        'Temperature'       'T_{mean}'          'Tmean'             SETUP.Tscale        SETUP.TDim       	true            %6
        'Max. Temperature'  'T_{max}'           'Tmax'              SETUP.Tscale        SETUP.TDim       	false           %7
        'Min. Velocity'     'v_{min}'           'Vmin'              SETUP.Vscale        SETUP.vDim       	false           %8
        'Velocity'          'v_{mean}'        	'Vrms'              SETUP.Vscale        SETUP.vDim       	true            %9
        'Max. Velocity'     'v_{max}'           'Vmax'              SETUP.Vscale        SETUP.vDim       	false           %10
        'Min. Viscosity'    '\eta_{min}'        'eta_min'         	SETUP.etascale    	SETUP.etaDim     	false           %11
        'Viscosity'         '\eta_{mean}'       'eta_mean'        	SETUP.etascale     	SETUP.etaDim     	true            %12
        'Max. Viscosity'    '\eta_{max}'        'eta_max'         	SETUP.etascale    	SETUP.etaDim      	false           %13
        'Ra_{eff}'          'Ra_{eff}'          'ra_eff'           	1                   ''                  false           %14
        'Nu_{top}'          'Nu_{top}'          'Nu_top'          	1                   ''                  false           %15
        'Nu_{bot}'          'Nu_{bot}'          'Nu_bot'           	1                   ''                  false           %16
        'Min. Composition' 	'C_{min}'           'C_min'             1                   ''                  false           %17
        'Composition'     	'C_{mean}'        	'C_mean'          	1                   ''                  true            %18
        'Max. Composition' 	'C_{max}'          	'C_max'             1                   ''                  false           %19
        'Mean Melt Fraction' 'F_{mean}'       	'F_mean'           	1                   ''                  false           %20
        'Max. Melt Fraction' 'F_{max}'       	'F_max'             1                   ''                  false           %21
        'Eruption Rate'     'UCvarepsilondot'  	'erupt_rate'      	SETUP.eruptratescale SETUP.eruptrateDim	false           %22
        'Erupta'            'erupta'            'erupta'          	SETUP.rhoscale      SETUP.rhoDim    	false           %23
        'Eruption Heatflux' 'hf_{erupt}'        'erupt_heatflux'   	SETUP.HFscale    	SETUP.HFDim       	false           %24
        'Entrainment'       'en'                'entrainment'      	1                   ''                  false           %25
        'Conserv. Error'    'Cmass_{err}'       'Cmass_error'     	1                   ''                  false           %26
        'Internal Heating'  'H_{int}'           'H_int'          	SETUP.Hscale        SETUP.HDim       	false           %27
        ...%additions in latest StagYY: (need to be completed)
        'Total Erupta'      'Erupta_{Total}'    'erupta_total'    	SETUP.massscale  	SETUP.massDim    	false           %28
        'Outgassed Water'   'Out_{water}'       'outgassed_water'  	1                   ''                  false           %29
        'Surf. Temperature' 'T_{surf}'          'Tsurf'          	SETUP.Tscale        SETUP.TDim       	false           %30
        'CMB Temperature'   'T_{CMB}'           'Tcmb'          	SETUP.Tscale        SETUP.TDim       	false           %31
        'Psurf'             'P_{surf}'          'Psurf'          	1                   ''                  false           %32
        'Weathering'        'We'                'weathering'     	1                   ''                  false           %33
        'H_2O Total'        'm_{H2O}'           'mH2O_total'     	1                   ''                  false           %34
        'H_2O Mantle'       'm_{H2O,Mantle}'    'mH2O_mantle'     	1                   ''                  false           %35
        'H_2O Crust'        'm_{H2O,Crust}'     'mH2O_crust'    	1                   ''                  false           %36
        'H_2O dm'           'dm_{H2O}'          'dmH2O'          	1                   ''                  false           %37
        'Outgassed Carbon'  'Out_{carb}'        'outgassed_carbon' 	1                   ''                  false           %38
        'Outgassed Nitrogen' 'Out_{nitro}'      'outgassed_nitrogen' 1                  ''                  false           %39
        };
    
    if nColumns==17 %old stag version
        FIELD_M = {
            'Time Steps'        'cumul. time steps' 'istep'          	1                   '#'                 false           %1
            'Time'              'time'              'time'           	PLOT.timeConvert    PLOT.time2plotDim   false           %2
            'Top Heatflux'     	'F_{top}'           'F_top'             SETUP.HFscale      	SETUP.HFDim       	false           %3
            'Bottom Heatflux'  	'F_{bot}'           'F_bot'             SETUP.HFscale    	SETUP.HFDim       	false           %4
            'Min. Temperature'  'T_{min}'           'Tmin'              SETUP.Tscale        SETUP.TDim       	false           %5
            'Temperature'       'T_{mean}'          'Tmean'             SETUP.Tscale        SETUP.TDim       	true            %6
            'Max. Temperature'  'T_{max}'           'Tmax'              SETUP.Tscale        SETUP.TDim       	false           %7
            'Min. Velocity'     'v_{min}'           'Vmin'              SETUP.Vscale        SETUP.vDim       	false           %8
            'Velocity'          'v_{mean}'        	'Vrms'              SETUP.Vscale        SETUP.vDim       	true            %9
            'Max. Velocity'     'v_{max}'           'Vmax'              SETUP.Vscale        SETUP.vDim       	false           %10
            'Min. Viscosity'    '\eta_{min}'        'eta_min'         	SETUP.etascale    	SETUP.etaDim     	false           %11
            'Viscosity'         '\eta_{mean}'       'eta_mean'        	SETUP.etascale     	SETUP.etaDim     	true            %12
            'Max. Viscosity'    '\eta_{max}'        'eta_max'         	SETUP.etascale    	SETUP.etaDim      	false           %13
            'Ra_{eff}'          'Ra_{eff}'          'ra_eff'           	1                   ''                  false           %14
            'Nu_{top}'          'Nu_{top}'          'Nu_top'          	1                   ''                  false           %15
            'Nu_{bot}'          'Nu_{bot}'          'Nu_bot'           	1                   ''                  false           %16
            'Internal Heating'  'H_{int}'           'H_int'          	SETUP.Hscale        SETUP.HDim       	false           %17
            };
    end
    
    % UNICODE VARIABLES
    %use the following character sequence to add unicode variables:
    %UCvarepsilondot => char(941)
    %UCvarepsilon => char(949)
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilondot',{char(941)});  %does only work if string consists ONLY of unicode character
    FIELD_M(:,2) = strrep(FIELD_M(:,2),'UCvarepsilon',{char(949)});     %does only work if string consists ONLY of unicode character
    
    % FIELD VARIABLES ADJUSTMENTS
    if SWITCH.DimensionalInput
        FIELD_M{strcmp(FIELD_M(:,3),'ra_eff'),4}    = SETUP.eta0.*SETUP.Ra0;    %undo Ra_eff = Ra_0/eta_mean if dimensional mode - set new Ra-scale
    end
    if SWITCH.DimensionalMode || SWITCH.DimensionalInput
        %nothing to do
    else
        %adjust for non-dimensional parameters
        FIELD_M(:,4) = {1};
        FIELD_M(:,5) = {'nd'};
    end
    
    %% DISPLAY MODEL DETAILS II
    disp(['Top-BC:            ',SETUP.topBC])
    disp(['Time Range:        ',num2str(minTimeDim,3),' - ',num2str(maxTimeDim,3),' ',PLOT.time2plotDim])
    
    %% COLOURING ADJUSTMENTS
    if strcmp(STYLE.ColorMode,'dark'); lineColor = 1-lineColor; end
    
    %% PLOTTING
    RemoveXLabel = ones(nrPlots,1);
    num_subplot=0;
    for iPlot=1:nrPlots
        %set parameter to plot
        if DATA.titleRow
            numField  	= find(strcmp(DATA.title,DATA.string(iPlot)));
        else
            numField   	= find(strcmp(FIELD_M(:,3),DATA.string(iPlot)));
        end
        
        %skip current parameter if not available in timedat file
        fieldFound      = true;
        if isempty(numField) || numField>nColumns
            fieldFound      = false;
            if SWITCH.Verbose
                warning off backtrace
                disp(' ')
                warning(['''',DATA.string{iPlot},''' not available in current time.dat file!']);
                disp(' ')
                warning on backtrace
            end
        end
        
        %set current variables
        if fieldFound
            FIELD.name          = FIELD_M{numField,1};
            FIELD.symbol        = FIELD_M{numField,2};
            FIELD.dim           = FIELD_M{numField,5};
            FIELD.logarithmic   = false; %dummy needed for f_DesignVaria
        else
            try
                FIELD.name          = FIELD_M{strcmp(FIELD_M(:,3),DATA.string{iPlot}),1};
            catch
                FIELD.name          = DATA.string(iPlot);
            end
            FIELD.symbol        = '';
            FIELD.dim           = '';
            FIELD.logarithmic   = false; %dummy needed for f_DesignVaria
        end

        %dimensionalise data
        if fieldFound
            DATA.Array{1,numField} = DATA.Array{1,numField}*FIELD_M{numField,4};
            if SWITCH.parameterRange && FIELD_M{numField,6} %parameter range
                DATA.Array{1,numField-1} = DATA.Array{1,numField-1}*FIELD_M{numField-1,4};
                DATA.Array{1,numField+1} = DATA.Array{1,numField+1}*FIELD_M{numField+1,4};
            end
        end
        
        if ~SWITCH.QuickMode
            %set subplot
            if nrPlots>1
                num_subplot	= num_subplot+1;
                hax         = subplot(nzSubplots,nxSubplots,num_subplot);
            end
            if iPlot==nrPlots || (PLOT.Performance && iPlot==nrPlots-1) ||...
                    (nrPlots>4 && iPlot==nrPlots-1) || (nrPlots>4 && PLOT.Performance && iPlot==nrPlots-2)
                RemoveXLabel(iPlot,1) = false;
            end
            hold on
            
            if ~fieldFound
                %insert empty plot
                dimStringTime           = FIELD_M{timeRow,5};
                DESVARIA.xlabelName     = FIELD_M{timeRow,1};
                DESVARIA.xlabelDim      = dimStringTime;
                DESVARIA.zlabelName     = FIELD.name;
                DESVARIA.zlabelDim      = FIELD.dim;
                DESVARIA.Task           = 'create annotation strings';
                [PLOT,DESVARIA,STYLE,SWITCH] = f_DesignVaria(DESVARIA,FIELD,[],SWITCH,PLOT,STYLE,SAVE);
                if SWITCH.SimplifyPlots && RemoveXLabel(iPlot,1)
                    %no xlabel
                else
                    xlabel(PLOT.xlabel);
                end
                ylabel(PLOT.ylabel)
%                 set(gca,'xtick',[]); set(gca,'ytick',[]);
                
                continue
                
            end
            
            %performance plot
            if PLOT.Performance && iPlot==nrPlots
                dt = zeros(size(DATA.Array{1,timeRow},1),1);
                for i=1:size(DATA.Array{1,timeRow},1)
                    if i==size(DATA.Array{1,timeRow},1)
                        dt(i,1) = DATA.Array{1,timeRow}(i,:)-DATA.Array{1,timeRow}(i-1,:);
                    else
                        dt(i,1) = DATA.Array{1,timeRow}(i+1,:)-DATA.Array{1,timeRow}(i,:);
                    end
                end
                pp1 = plot(DATA.Array{numField}, dt,'Color',lineColor);
                
                DESVARIA.xlabelName     = FIELD.name;
                DESVARIA.xlabelDim      = FIELD.dim;
                DESVARIA.zlabelName     = 'Time Step';
                DESVARIA.zlabelDim      = PLOT.time2plotDim;
                DESVARIA.Task           = 'create annotation strings';
                [PLOT,DESVARIA,STYLE,SWITCH] = f_DesignVaria(DESVARIA,FIELD,[],SWITCH,PLOT,STYLE,SAVE);
                xlabel(PLOT.xlabel)
                ylabel(PLOT.ylabel)
                
                grid on
                if SWITCH.MinMaxLegend
                    legend('^{dt}/_{time step}')
                end
                h_runs(irun,1) = pp1;
                break
            end
            
            %time plot
            if SWITCH.parameterRange && FIELD_M{numField,6}
                colourMax       = [0.64 0.08 0.18];
                colourMin       = [0.0 0.45 0.74];
                if PLOT.rangeAsArea
                    %min-max area
                    edgecolor   = 'none';
                    areaAlpha   = 0.2;
                    hold on
                    maxData     = DATA.Array{numField+1};
                    minData     = DATA.Array{numField-1};
                    xData       = DATA.Array{1,timeRow};
                    pp4 = fill([xData' fliplr(xData')],[maxData' fliplr(minData')],...
                        lineColor,'EdgeColor',edgecolor,'EdgeAlpha',areaAlpha,'FaceAlpha',areaAlpha);
                else
                    %min/max lines
                    hold on
                    pp2 = plot(DATA.Array{1,timeRow}, DATA.Array{numField-1},'Color',colourMin); 	%minimum
                    pp3 = plot(DATA.Array{1,timeRow}, DATA.Array{numField+1},'Color',colourMax);	%maximum
                end
                pp1 = plot(DATA.Array{1,timeRow}, DATA.Array{numField},'Color',lineColor);   %mean
                
                if SWITCH.MinMaxLegend
                    if PLOT.rangeAsArea
                        legend([pp1,pp4],[FIELD_M(numField,2),strcat(FIELD_M(numField-1,2),'-',FIELD_M(numField+1,2))])
                    else
                        legend([pp3,pp1,pp2],[FIELD_M(numField+1,2),FIELD_M(numField,2),FIELD_M(numField-1,2)],'Location','Best');
                    end
                end
            else
                pp1 = plot(DATA.Array{1,timeRow}, DATA.Array{numField},'Color',lineColor);   %mean
                if SWITCH.MinMaxLegend
                    legend(pp1,FIELD_M(numField,2),'Location','Best');
                end
            end
            h_runs(irun,1) = pp1;
            
            %axes labelling
            dimStringTime           = FIELD_M{timeRow,5};
            DESVARIA.xlabelName     = FIELD_M{timeRow,1};
            DESVARIA.xlabelDim      = dimStringTime;
            DESVARIA.zlabelName     = FIELD.name;
            DESVARIA.zlabelDim      = FIELD.dim;
            DESVARIA.Task           = 'create annotation strings';
            [PLOT,DESVARIA,STYLE,SWITCH] = f_DesignVaria(DESVARIA,FIELD,[],SWITCH,PLOT,STYLE,SAVE);
            if SWITCH.SimplifyPlots && RemoveXLabel(iPlot,1)
                %no xlabel
            else
                xlabel(PLOT.xlabel);
            end
            ylabel(PLOT.ylabel)
            grid on
        end
        
        %remember graph data to be saved
        if SAVE.Graphs && fieldFound
            %create array to save
            if ~exist('titleArray','var'); titleArray = {[FIELD_M{timeRow,1},'[',FIELD_M{timeRow,5},']']}; dataArray = DATA.Array{1,timeRow}; end
            titleArray              = [titleArray, {[FIELD.name,'[',FIELD.dim,']']}];
            dataArray               = [dataArray, DATA.Array{numField}];
        end
    end %loop
    disp(' ')
end

%% SAVING GRAPH DATA
if SAVE.Graphs
    SAVE.Directory     	= FILE.directory;
    SAVE.DataName      	= [FILE.name,'_TimeGraphs'];
    SAVE.DataTitle    	= strjoin(titleArray,', ');
    SAVE.data          	= dataArray;
    [SAVE.overwriteAll] = f_saveData( SAVE );
    SAVE                = rmfield(SAVE,{'data','DataTitle'});
end

%% LEGEND
if ~SWITCH.MinMaxLegend && ~SWITCH.QuickMode %not applied if individual legends are switched on
    if isfield(PLOT,'titleString'); legendANN = PLOT.titleString; else; legendANN = IN.Name; end
    hl = legend(h_runs, legendANN, 'Location', 'NorthEast', 'interpreter', 'none');
    % hl = legend(h_runs, IN.Name, 'Location', 'SouthEast');
end

%% STYLE PLOT
if SWITCH.PlotDesign
    %     STYLE.Legend = false; %done later
    if SWITCH.LegendDesign; STYLE.Legend = true; else; STYLE.Legend = false; end
    f_DesignFigure(STYLE);
end
if SWITCH.BackgroundDesign
    BACK.ApplyTo    = 'all';          %'current', 'all'
    BACK.ColorMode  = STYLE.ColorMode;
    f_DesignBackground(BACK) %set plot background of each subplot
end

%% ANNOTATION
if SWITCH.Annotation
    %     pause(0.5);
    f_DesignAnnotations(PLOT,STYLE);
end

%% fAIO ACTION: FINISHING UP
fAIo.task = 'finishingUp';
[fAIo,SAVE] = f_AIo(fAIo,SWITCH,FILE,[],STYLE,SAVE);

%% SAVING PLOTS
if SAVE.Figure
    % SAVING DIRECTORY
    if strcmp(SAVE.writeDirectory,'auto') %save to standard folder (e.g., .../+im/...)
        SAVE.Directory          = FILE.stemSave;
    else
        SAVE.Directory          = SAVE.writeDirectory;
    end
    if strcmp(STYLE.ColorMode,'light')
        SAVE.blackBackground    = false;
    elseif strcmp(STYLE.ColorMode,'dark')
        SAVE.blackBackground    = true;
    end
    endix                       = [strjoin(IN.Name,'_'),'_',strjoin(DATA.string,'')];
    if SWITCH.DimensionalMode;          endix = [endix,'Dim'];   	end
    if strcmp(STYLE.ColorMode,'dark');  endix = [endix,'Dark'];   	end
    SAVE.FigureName             = strcat(IN.saveString,'_',endix);   %file name
    SAVE.FigureNr               = 1;
    f_saveFigure( SAVE )
end

%% FINISHING UP
disp(' ')
disp(['                         ',char(10004),' Finished.']);










