
%%                                                 DEFAULT INPUT VARIABLES
%                                                          for STAGtimedat

function [IN,PLOT,SWITCH,STYLE,SAVE] = f_DefaultsTimedat
if ~exist('STAGtimedat','file'); f_INSTALL; end

%% DEBUGGING
SWITCH.Verbose                  =   logical(0);                 %Switch for extended display output

%% INPUT FILE(S)
SWITCH.GeodynamicCode           =   'StagYY';                	%To use StagLab with a different code, run and adjust at locations of error messages
IN.Name                         =   { 'test'  'test' };         %Filename (it's size controls the # of files processed)
IN.Parameter                    =   [   11         ];           %Parameter dimensionalisation (see f_Dimensions)
IN.Folder                       =   {'/work/stagyy140211/'};    %File directory
% PLOT.titleString               =   {'case1' 'case2'};      	%Manual legend description if uncommented

%% StagLab MODES
SWITCH.DimensionalMode      	=   logical(0);                 %Converts to dimensional output as set in f_Dimensions.m
    SWITCH.modelSetup           =   'standard';             	%See f_Dimensions, e.g., 'standard', 'solomatov2004'
SWITCH.QuickMode                =   logical(0);                 %Omits plotting graphs for faster post-processing of files
STYLE.ColorMode                 =   'light';                    %'light' or 'dark' figure background

%% FIGURE SETUP
SWITCH.FigurePosition           =   'auto';                     %'auto' or set manually by e.g., [47 1 1300 350]
PLOT.FigureDefaultPosition      =   'TopRight';                 %Figure position on screen: 'BottomLeft', 'BottomRight', 'TopLeft', or 'TopRight'
    
%% STYLING
SWITCH.BackgroundDesign      	=   logical(1);
SWITCH.PlotDesign               =   logical(1);
SWITCH.LegendDesign         	=   logical(1);
SWITCH.SimplifyPlots         	=   logical(1);
%font
STYLE.AllFontName               =   'Open Sans';                %e.g. 'Helvetica','Corbel','Eurostyle','ETH Light','Open Sans'
STYLE.keyFontSize               =   10;
%colours
STYLE.keyColor                  =   [0.5 0.5 0.5];              %Key colour used for text and axes

%% APP PERFORMANCE
IN.numWrite                     =   1;                          %CURRENTLY REMOVED! writes out every 'num_write' time step

%% PLOT ADDITIONS & LABELLING
SWITCH.parameterRange           =   logical(0);                 %Plotting mean, min & max
   	PLOT.rangeAsArea            =   logical(1);                 %min/max range as area
    SWITCH.MinMaxLegend         =   logical(0);              	%Legend switch for min and max lines

%% LABELLING
SWITCH.Annotation               =   logical(1);                 %Subplot annotations with e.g., 'a', 'b', 'c'
    STYLE.annotationLocation    =   'botLeft';                  %'topOutTop','topOutCorner','topLeft','botLeft','topRight','botRight'
    PLOT.annotationString     	=   {'a' 'b' 'c' 'd' 'e' 'f' 'g' 'h' 'i' 'j' 'k' 'l' 'm' 'n' 'o' 'p'};  %subplot annotation strings
    PLOT.annIfMoreThanOne       =   logical(1);                 %Add annotation only if more than 1 subplot

%% PARAMETER(S) TO PLOT
PLOT.Temperature                =   logical(1);
PLOT.Viscosity                  =   logical(1);
PLOT.Velocity                   =   logical(1);
PLOT.Composition                =   logical(0);

PLOT.Ra_eff                     =   logical(1);   %only 1 value
PLOT.Nu_top                     =   logical(0);   %only 1 value
PLOT.Nu_bot                     =   logical(0);   %only 1 value
PLOT.InternalHeating            =   logical(1);   %only 1 value
PLOT.HeatfluxTop                =   logical(0);   %only 1 value
PLOT.HeatfluxBot                =   logical(0);   %only 1 value
PLOT.EruptionRate               =   logical(0);   %only 1 value
PLOT.EruptHeatFlux              =   logical(0);   %only 1 value
PLOT.Erupta                     =   logical(0);   %only 1 value
PLOT.Entrainment                =   logical(0);   %only 1 value
PLOT.Cmass_error                =   logical(0);   %only 1 value
PLOT.Timesteps                  =   logical(0);   %only 1 value
PLOT.Performance                =   logical(1);   %only 1 value
 
%New options: need to be tested!
PLOT.TotalErupta                =   logical(0);   %only 1 value
PLOT.OutgassedWater             =   logical(0);   %only 1 value
PLOT.SurfaceTemperature         =   logical(0);   %only 1 value
PLOT.CMB_Temperature            =   logical(0);   %only 1 value
PLOT.Psurf                      =   logical(0);   %only 1 value
PLOT.Weathering                 =   logical(0);   %only 1 value
PLOT.TotalWater                 =   logical(0);   %only 1 value
PLOT.MantleWater                =   logical(0);   %only 1 value
PLOT.CrustWater                 =   logical(0);   %only 1 value
PLOT.dmH2O                      =   logical(0);   %only 1 value
PLOT.OutgassedCarbon            =   logical(0);   %only 1 value
PLOT.OutgassedNitrogen          =   logical(0);   %only 1 value

%% COLOUR SET FOR MULTIPLE LINES
PLOT.ColorVector                = [ 
    0.0 0.0 0.0
    0.0 0.45 0.74
    0.49 0.18 0.56
    0.85 0.32 0.1
    0.93 0.69 0.13
    1.0 0.0 1.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    ];

%% SAVING
SAVE.Figure                   	=   logical(0);                 %Saves plot to directory   
    SAVE.png                    =   logical(1);
        SAVE.pngResolution      =   '-m4.0';
    SAVE.jpg                    =   logical(0); 
        SAVE.jpgResolution    	=   '-r400';
    SAVE.eps                    =   logical(0); 
    SAVE.pdf                    =   logical(0); 
    IN.saveString               =   '+Evolution';
  	SAVE.writeDirectory         =   'auto';                     %'auto': save to standard folder (.../+im/...); otherwise use e.g., '/work/stagyy/'

%% SAVING DATA
SAVE.Graphs                     =   logical(0);                 %Saves processed plotted graphs to data files
    SAVE.mat                    =   logical(0);
    SAVE.dat                    =   logical(1);
    SAVE.txt                    =   logical(0);

end









