
%%                                                          EMPTY PLOT 1.21
%   .calls f_DesignLayout
%   .calls f_DesignLayoutPosition
%   .calls f_DesignVaria
%                                                Fabio Crameri, 11.05.2017

function [PLOT,SAVE] = f_EmptyPlot(SWITCH,PLOT,GRID,FIELD,STYLE,SAVE)

%% VARIABLE DEFINITIONS
minX            = min(GRID.X_3Dp(:));
minZ            = min(GRID.Z_3Dp(:));
maxX            = max(GRID.X_3Dp(:));
maxZ            = max(GRID.Z_3Dp(:));
if strcmp(GRID.Type,'cylindrical')
    minX            = min(GRID.x2ds(:));
    minZ            = min(GRID.z2ds(:));
    maxX            = max(GRID.x2ds(:));
    maxZ            = max(GRID.z2ds(:));
end
dZ              = maxZ-minZ;
crossThick      = dZ *1/5;

%% DESIGN INPUT
crossColor   	= [0.81 0.81 0.81];
if strcmp(STYLE.ColorMode,'dark')
    crossColor = 1-crossColor;
end

%% COUNT SUBPLOTS
PLOT.nrSubplot = PLOT.nrSubplot+1;

%% SETUP FIGURE
figure(1)

%% SUBPLOT LAYOUT
SPOS.task   = 'createSubplot';
[SP,SAVE] = f_DesignLayoutPosition(SPOS,PLOT,SWITCH,SAVE);

%% CURRENT AXIS
AXcurrent = gca; %save current axes handle

%% COLORBAR
colorbar;   %define dummy colorbar
cb = NaN; 	%this is a flag if no colorbar is used

%% DRAW CROSS PATCH
xleft   = minX; % + dX/4;
xright  = maxX; % - dX/4;
% dX2     = xright-xleft;
% mid     = minZ+dZ/2;
%     patch([xleft, xleft+plateThick, xleft+dX2/2, xright-plateThick, xright, xright-dX2/2+plateThick/2, xright, xright-plateThick, xleft+dX2/2, xleft+plateThick, xleft, xleft+dX2/2-plateThick/2],...
%           [minZ,  minZ,             mid-plateThick/2,     minZ,            minZ,     mid,                maxZ,   maxZ,              mid+plateThick/2,     maxZ,            maxZ, mid],...
%         plateColor,'FaceAlpha',0.1,'EdgeColor','none')
patch([xleft, xleft+crossThick, xright, xright-crossThick],...
    [maxZ,  maxZ,             minZ,            minZ],...
    crossColor,'FaceAlpha',1.0,'EdgeColor','none')
patch([xleft, xleft+crossThick, xright, xright-crossThick],...
    [minZ,  minZ,             maxZ,            maxZ],...
    crossColor,'FaceAlpha',1.0,'EdgeColor','none')

%% ANNOTATIONS
%title
DESVARIA.fieldName     = [FIELD.name,' n.a.'];
DESVARIA.Task    = 'create annotation strings';
[PLOT,DESVARIA,STYLE,SWITCH] = f_DesignVaria(DESVARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);

DESVARIA.Task    = 'make title';
[PLOT,DESVARIA,STYLE,SWITCH] = f_DesignVaria(DESVARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);

%adjust axis
axis([minX maxX minZ maxZ]) %fix axis
axis off

%% SIMPLIFY FIGURE ==================================
if SWITCH.SimplifyPlots
    %SET AXES ASPECT RATIO ----
    XaxisAR     = GRID.aspectRatio(1); 
    XaxisARmax  = PLOT.MaxAspectX; if strcmp(GRID.Type,'Cartesian'); XaxisARmax = 999; end
    if strcmp(GRID.Type,'cylindrical'); XaxisAR = 1; end
    YaxisAR     = 1;
    ZaxisAR     = 1;
    set(gca,'PlotBoxAspectRatio',[min(XaxisARmax,XaxisAR) YaxisAR ZaxisAR])
    %--------------------------
    
    %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
    PLOT.spcurrent          = SP.current;
    PLOT.sp_chax            = AXcurrent;
    if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else; PLOT.sp_chaxz = NaN; end
    PLOT.sp_ccb             = cb;   %colorbar handle
    PLOT.title              = 'Empty plot';  	%title string
    
    [PLOT] = f_DesignLayout(SWITCH,PLOT,GRID,FIELD);
end

%.........
drawnow  %actually only needed if topo or other graph plot is included (axis change otherwise)
%.........

%% FUNCTION OUTPUT
if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else; nr_hax = 1; end
PLOT.hax(nr_hax,1)  = AXcurrent;
SAVE.PlotHandles    = [SAVE.PlotHandles; AXcurrent];



