
%%                                          SETUP 2-D PARAMETER FIELDS 2.0

%                                                Fabio Crameri, 07.04.2017

function [FIELD,PLOT,SAVE] = f_Setup2DField(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,SAVE)

%% DEFAULTS
FIELD2D.saveData        = logical(0);

%% PARAMETER FIELDS
if strcmp(FIELD.name,'Heat Flux')
    Tfieldname          = 'Heat Flux';
    
elseif strcmp(FIELD.name,'Surface Age')
    Tfieldname          = 'Surface Age';

elseif strcmp(FIELD.name,'Crustal Thickness')
    Tfieldname          = 'Crustal Thickness';
    
else
    error('fc: unknown Tfieldname')
end

%% READ 2-D FIELD
[~,X_3D,Y_3D,~,FIELD_3D,~,~]  = f_readStagYY(FILE.directory,FILE.name,FILE.number,Tfieldname,SWITCH);
if ischar(X_3D); error(X_3D); end
if size(FIELD_3D,1)==1 %exchange x and y
    dummy_3D = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
    dummy_3Dx = zeros(size(Y_3D,2),size(Y_3D,1),size(Y_3D,3));
    dummy_3D(:,1,:) = FIELD_3D(1,:,:);  FIELD_3D = dummy_3D;
    dummy_3Dx(:,1,:) = X_3D(1,:,:);
    dummy_3D(:,1,:) = Y_3D(1,:,:); Y_3D = dummy_3Dx; X_3D = dummy_3D;
end
if strcmp(GRID.Dim,'2-D')
    x2d             = X_3D(:,1,1);
    y2d             = Y_3D(1,:,1)';
    field2d(:,:)    = FIELD_3D(:,1,:);
elseif strcmp(GRID.Dim,'3-D')
    x2d(:,:)        = X_3D(:,1,1);
    y2d(:,:)        = Y_3D(1,:,1)';
    field2d(:,:,:)  = FIELD_3D(:,:,:);
end

%% DIAGNOSE 2-D FIELD
numFields           = size(field2d,3);

%% ADJUST 2-D FIELD
if strcmp(FIELD.name,'Heat Flux')
    %flip cmb and surface data
    field2d         = fliplr(field2d);
end

%% PLOTTING OPTIONS
%e.g., SWITCH.plotDifference

% if SWITCH.plotDifference && strcmp(FIELD2D.difference,'comp')
%     if iloopComp==1
%         PLOT.field2d_B = field2d;
%         field2d     = PLOT.field2d_A;
%     else
%         field2d     = PLOT.field2d_B;
%     end
% end

%% SMOOTHING
field_smooth_2      = zeros(size(field2d));
field_smooth_1      = field2d;
if strcmp(GRID.Dim,'2-D')
    %------------------------
    % SMOOTHING 2-D
    %------------------------
    smoothingMethod = 3;
    if smoothingMethod==1 %DOESN'T WORK FOR 2-D YET!!!!!!!!! FIELD2D BECOMES SMALL!?
        filterSize = 5; %has to be an odd number!!!!
        %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
        %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
        F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
        F = F(:,ceil(end/2)); %convert for 2D
        
        %add ghost points to prevent side effects from smoothing
        dummy = field_smooth_1; %surf and cmb
        for ii=1:filterSize
            dummy = [dummy(1,:); dummy; dummy(end,:)];
        end
        field_smooth_2 = zeros(size(dummy));
        %smoothing
        for jj=1:17
            field_smooth_2(:,1) = conv(dummy(:,1),F,'same');
            if numFields>1
                field_smooth_2(:,2) = conv(dummy(:,2),F,'same');
            end
            dummy = field_smooth_2;
        end
        %remove ghostpoints
        field_smooth_2 = dummy(filterSize+1:end-filterSize,:);
        
    elseif smoothingMethod==2
        for jj=1:2
            field_smooth_2(:,1) = smooth(field_smooth_1(:,1),5,'loess');
            if numFields>1
                field_smooth_2(:,2) = smooth(field_smooth_1(:,2),5,'loess');
            end
            field_smooth_1 = field_smooth_2;
        end
    elseif smoothingMethod==3
        for jj=1:2
            field_smooth_2(:,1) = smooth(field_smooth_1(:,1),5,'moving');
            if numFields>1
                field_smooth_2(:,2) = smooth(field_smooth_1(:,2),5,'moving');
            end
            field_smooth_1 = field_smooth_2;
        end
    end
    field_smooth = field_smooth_2;

    
elseif strcmp(GRID.Dim,'3-D')
    if numFields==1
        field_PLOT = field2d(:,:,1);
    else
        warning('Currently only one field plot available at once - Check here!')
        field_PLOT = field2d(:,:,2); %surf field
%         field_PLOT = field2d(:,:,1); %cmb field
    end
    if SWITCH.plotFIELDsmooth
        %------------------------
        % SMOOTHING 3-D
        %------------------------
        smoothingMethod = 1;
        if smoothingMethod==1
            filterSize = 5;
            %F = [.05 .1 .05; .1 .4 .1; .05 .1 .05]; %filter
            %F = [1/9 1/9 1/9; 1/9 1/9 1/9; 1/9 1/9 1/9]; %like 2-D filter - with one loop!
            F = fspecial('gaussian',filterSize); %filterSize is the size of matrix
            %F = fspecial('gaussian');
            
            %add ghost points to prevent side effects from smoothing
            dummy = field_PLOT;
            for ii=1:filterSize
                dummy = [dummy(1,:); dummy; dummy(end,:)];
                dummy = [dummy(:,1), dummy, dummy(:,end)];
            end
            %smoothing
            for jj=1:17
                field_PLOTsmooth = conv2(dummy,F,'same');
                dummy = field_PLOTsmooth;
            end
            %remove ghostpoints
            field_PLOTsmooth = dummy(filterSize+1:end-filterSize,filterSize+1:end-filterSize);
            
        elseif smoothingMethod==2
            %according to smooth2a
            Nr = 3; %rows
            Nc = 3; %colums
            % You end up replacing element "i" by the mean of a (2*Nr+1)-by-
            % (2*Nc+1) rectangle centered on element "i".
            [row,col] = size(field_PLOT);
            eL = spdiags(ones(row,2*Nr+1),(-Nr:Nr),row,row);
            eR = spdiags(ones(col,2*Nc+1),(-Nc:Nc),col,col);
            % Setting all "NaN" elements of "matrixIn" to zero so that these will not
            % affect the summation.  (If this isn't done, any sum that includes a NaN
            % will also become NaN.)
            A = isnan(field_PLOT);
            field_PLOT(A) = 0;
            % For each element, we have to count how many non-NaN elements went into
            % the sums.  This is so we can divide by that number to get a mean.  We use
            % the same matrices to do this (ie, "eL" and "eR").
            nrmlize = eL*(~A)*eR;
            nrmlize(A) = NaN;
            % Actually taking the mean.
            field_PLOTsmooth = eL*field_PLOT*eR;
            field_PLOTsmooth = field_PLOTsmooth./nrmlize;
        end
    end
end

%% DIMENSIONALISATION
if strcmp(GRID.Dim,'2-D')
    x_PLOT          = x2d(:,1)      *GRID.dimFactor;
    field_PLOT      = field2d       *FIELD.varScale;
    fieldSmooth_PLOT= field_smooth  *FIELD.varScale;
else
    x_PLOT          = x2d(:,1)      *GRID.dimFactor;
    y_PLOT          = y2d(:,1)      *GRID.dimFactor;
    field_PLOT      = field_PLOT  	*FIELD.varScale;
    field_PLOTsmooth= field_PLOTsmooth *FIELD.varScale;
end

if strcmp(GRID.Dim,'2-D')
    %% SAVING FIELD ------------------------
    if FIELD2D.saveData
        error('not adjusted yet!');
        SAVE.Directory              = FILE.directory;
        SAVE.DataName               = [FILE.name,'_heatflux',num2str(FILE.number)];
        SAVE.data                   = [x_PLOT, field_PLOT, fieldSmooth_PLOT]; %[x, field, field_smooth]
        SAVE.dat                    = logical(0);
        SAVE.txt                    = logical(0);
        SAVE.mat                    = logical(1);
        SAVE.write2existing         = logical(0);
        [SAVE.overwriteAll] = f_saveData( SAVE );
    end
    
    %% PLOTTING FIELD ----------------------------------------------
    if SWITCH.plotFIELDtrue; i_start=1; else; i_start=2; end
    if SWITCH.plotFIELDsmooth; i_end=2; else; i_end=1; end
    
    %plot field
    for i_field=i_start:i_end
        if i_field==1 %plot true field
            field2plot = field_PLOT;
        elseif i_field==2 %plot smooth field
            field2plot = fieldSmooth_PLOT;
        end
    end
    
    
elseif strcmp(GRID.Dim,'3-D')
    %% 3-D
    if SWITCH.plotFIELDtrue && SWITCH.plotFIELDsmooth
        n_start     = 1;
        n_end       = 2;
    elseif SWITCH.plotFIELDtrue
        n_start     = 1;
        n_end       = 1;
    elseif SWITCH.plotFIELDsmooth
        n_start     = 2;
        n_end       = 2;
    end
    for i_field=n_start:n_end
        if i_field==1 %plot field
            field2plot = field_PLOT;
        elseif i_field==2 %plot field smooth
            field2plot = field_PLOTsmooth;
        end
    end %3-D
    
end

%% ADJUSTMENTS FOR FUNCTION OUTPUT
clearvars field2d

%% OUTPUT
FIELD.field2d        	= field2plot;



